@@ -4,7 +4,7 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.09_01';
+our $VERSION = '0.11_01';
 
 use File::Spec;
 use YAML::XS qw( LoadFile );
@@ -43,10 +43,10 @@ Hash::Merge::specify_behavior(
 
 
 sub new {
-  my $self_class = shift;
-  my %params     = @_;
+  my $class  = shift;
+  my %params = @_;
 
-  my $self = bless {}, $self_class;
+  my $self = bless {}, $class;
 
   $self->{dirs} = $params{dirs} || [];
   push( @{ $params{dirs} }, '.' );
@@ -473,7 +473,7 @@ After merging of two files we will get:
 =head1 INTERPOLATION
 
 Config::Processor can interpolate variables in string values (if you need alias
-for complex sctructures see C<var> directive). For example, we have
+for complex structures see C<var> directive). For example, we have
 F<myapp.yml> file:
 
   myapp:
@@ -651,14 +651,14 @@ configuration parameters.
           host:     "stat-master.mydb.com"
           username: "stat_writer"
           password: "stat_writer_pass"
-          overlay: { var: myapp.db.connectors.test }
+          overlay:  { var: myapp.db.connectors.test }
 
         stat_slave:
           underlay: { var: myapp.db.connectors.default }
           host:     "stat-slave.mydb.com"
           username: "stat_reader"
           password: "stat_reader_pass"
-          overlay: { var: myapp.db.connectors.test }
+          overlay:  { var: myapp.db.connectors.test }
 
 To disable overriding just assign to C<test> connector empty hash.
 
